@@ -7,8 +7,13 @@ use crate::geometry::delta_decode;
 // Read a single point geometry
 pub fn read_point(x: Option<CompressedGeometry>, trans: &Translate, scale: &Scale) -> Robj {
     if x.is_none() {
-        let empty_pnt = Doubles::from_values([Rfloat::na(); 2]);
-        return empty_pnt.into();
+        let empty_pnt = Doubles::from_values([Rfloat::na(); 2])
+            .into_robj()
+            .set_class(&["XY", "POINT", "sfg"])
+            .unwrap()
+            .clone();
+
+        return empty_pnt;
     }
 
     let mut crds = match x.unwrap() {
@@ -18,7 +23,10 @@ pub fn read_point(x: Option<CompressedGeometry>, trans: &Translate, scale: &Scal
 
     let crds = delta_decode(&mut crds, trans, scale);
     let res = Doubles::from_values(crds[0]);
-    res.into_robj().set_class(&["XY", "POINT", "sfg"]).unwrap()
+    res.into_robj()
+        .set_class(&["XY", "POINT", "sfg"])
+        .unwrap()
+        .clone()
 }
 
 pub fn read_multipoint(x: Option<CompressedGeometry>, trans: &Translate, scale: &Scale) -> Robj {
@@ -26,7 +34,11 @@ pub fn read_multipoint(x: Option<CompressedGeometry>, trans: &Translate, scale:
         let empty_mpnt = Doubles::new(0)
             .into_robj()
             .set_attrib("dim", Integers::from_values([0, 2]))
-            .unwrap();
+            .unwrap()
+            .set_class(&["XY", "MULTIPOINT", "sfg"])
+            .unwrap()
+            .clone();
+
         return empty_mpnt;
     }
 
@@ -40,4 +52,5 @@ pub fn read_multipoint(x: Option<CompressedGeometry>, trans: &Translate, scale:
     RMatrix::new_matrix(decoded.len(), 2, |r, c| decoded[r][c])
         .set_class(&["XY", "MULTIPOINT", "sfg"])
         .unwrap()
+        .clone()
 }
